ATCommon class
Constructors
- ATCommon()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getAdATBannerAdShowingPositionBottom(
) → String -
getAdATBannerAdShowingPositionTop(
) → String -
getAdSizeKey(
) → String -
getBiddingAttemptKey(
) → String -
getLoadingKey(
) → String -
getMediaViewFrameKey(
) → String - iOS 支持:原生广告加载时传入 mediaView 的 frame。
-
getNativeRenderTypeExpress(
) → String -
getNativeRenderTypeKey(
) → String -
getNativeRenderTypeSelfRender(
) → String -
getShowCustomExtKey(
) → String -
isNativeShow(
) → String -
loadNativeAd的分流标记(写在extraMap里)。